@@ -2,6 +2,7 @@
 #define BONUSDISCIPLINEWINDOW_H
 
 #include <QDialog>
+#include <QCheckBox>
 #include "core/player.h"
 #include "randomnumberpicker.h"
 
@@ -14,19 +15,23 @@ class BonusDisciplineWindow : public QDialog
     Q_OBJECT
 
 public:
-    explicit BonusDisciplineWindow(QWidget *parent = 0, Book* book=0, Player* player=0);
+    explicit BonusDisciplineWindow(QWidget *parent = 0, Book* book=0, Player* player=0, int number=1);
     ~BonusDisciplineWindow();
 
 private:
     Ui::BonusDisciplineWindow *ui;
 
+    int m_Number;
+    int m_Selected;
     Book* m_Book;
     RandomNumberPicker* m_RandomPicker;
     int m_Serie;
     Player* m_Player;
     QList<KaiDiscipline*> m_List;
     QList<QPushButton*> m_Buttons;
+    QList<QCheckBox*> m_CheckButtons;
 
+    QStringList m_Elements;
     QString m_RandomSender;
 
     void ShowData();
@@ -37,6 +42,8 @@ private slots:
     void RandomSlot();
     void GetRandomSlot(int);
     void DiscipleLinkSlot(QString link);
+    void SelectSlot(bool selected);
+    void OkSlot();
 };
 
 #endif // BONUSDISCIPLINEWINDOW_H
