@@ -15,6 +15,7 @@
 #include "shopwindow.h"
 #include "minigames/cartwheelwindow.h"
 #include "minigames/portholeswindow.h"
+#include "minigames/betwindow.h"
 #include "bookinfowindow.h"
 #include "inputnumberwindow.h"
 #include "core/books.h"
@@ -33,7 +34,7 @@ QDataStream &operator<<(QDataStream &out, const Player &player)
 {
     out << player.BaseCombatSkill << player.BaseEndurance
         << player.Endurance << player.GoldCrowns << player.HasBackpack() << player.DeathsCount << player.TemporaryCombatSkillDelta
-        << player.Properties << player.CanHunt();
+        << player.Properties << player.CanHunt() << player.HasQuiver() << player.Arrows;
     return out;
 }
 
@@ -41,12 +42,14 @@ QDataStream &operator>>(QDataStream &in, Player &player)
 {
     bool backpack = true;
     bool canHunt  = true;
+    bool quiver = true;
     in >> player.BaseCombatSkill >> player.BaseEndurance
        >> player.Endurance >> player.GoldCrowns >> backpack >> player.DeathsCount >> player.TemporaryCombatSkillDelta
-       >> player.Properties >> canHunt;
+       >> player.Properties >> canHunt >> quiver >> player.Arrows;
 
     player.SetHasBackpack(backpack);
     player.SetCanHunt(canHunt);
+    player.SetHasQuiver(quiver);
 
     return in;
 }
@@ -449,7 +452,9 @@ void BookWindow::SetChoiceText(QPushButton* button, QString text)
 void BookWindow::ExitSection()
 {
     if (m_Ate < m_Section->MustEat){
-        if (m_Section->CanHunt && m_Player->HasDiscipline("Hunting") && m_Player->CanHunt()){
+        if (m_Section->CanHunt &&
+            (m_Player->HasDiscipline("Hunting") || m_Player->HasDiscipline("Huntmastery")) &&
+            m_Player->CanHunt()){
             //nothing to do
         }else if (m_Player->MealsCount() < m_Section->MustEat){
             CommonStatic::Message(this, "Info", QString("You don't have enough meals and lose %1 ENDURANCE points.").arg(m_Section->DidntEatEnduranceLoss));
@@ -481,10 +486,14 @@ void BookWindow::ExitSection()
     }
     m_Player->TemporaryCombatSkillDelta = 0;
 
-    if (m_Player->HasDiscipline("Healing") && !m_Fought){
+    if (m_Book->GetSerie() == Book::Kai && m_Player->HasDiscipline("Healing") && !m_Fought){
+        if (m_Player->Endurance + 1 <= m_Player->GetBaseEndurance())
+            m_Player->Endurance += 1;
+    }else if (m_Book->GetSerie() == Book::Magnakai && m_Player->HasDiscipline("Curing") && !m_Fought){
         if (m_Player->Endurance + 1 <= m_Player->GetBaseEndurance())
             m_Player->Endurance += 1;
     }
+
 }
 
 void BookWindow::DoChoice(int number)
@@ -719,7 +728,7 @@ void BookWindow::StatusSlot()
 #ifndef Q_WS_MAEMO_5
     hide();
 #endif
-    StatusWindow* dlg = new StatusWindow(this, m_Book->GetSerie(), m_Player, m_Section, &m_Engine, &m_Functions);
+    StatusWindow* dlg = new StatusWindow(this, m_Player, m_Section, &m_Engine, &m_Functions);
     dlg->exec();
 
     foreach (Item* i, dlg->UsedItems()){
@@ -741,7 +750,7 @@ void BookWindow::PickItemsSlot()
 #ifndef Q_WS_MAEMO_5
     hide();
 #endif
-    StatusWindow* dlg = new StatusWindow(this, m_Book->GetSerie(), m_Player, m_Section, &m_Engine, &m_Functions);
+    StatusWindow* dlg = new StatusWindow(this, m_Player, m_Section, &m_Engine, &m_Functions);
     dlg->exec();
     delete dlg;
 #ifndef Q_WS_MAEMO_5
@@ -870,7 +879,9 @@ bool BookWindow::Load(QString filename)
     QVariant var = settings.value("player");
     if (var.isValid()){
         m_Player = new Player(var.value<Player>());
+#ifndef QT_NO_DEBUG
         m_Player->Dump();
+#endif
     }
 
     int index = settings.beginReadArray("items");
@@ -921,6 +932,7 @@ bool BookWindow::Load(QString filename)
         QString discipline = settings.value("kaidiscipline").toString();
         QStringList ele = discipline.split("|");
         KaiDiscipline* d = NULL;
+        // Kai:
         if (ele.at(0) == "Camouflage")
             d = new Camouflage(m_Player);
         else if (ele.at(0) == "Hunting")
@@ -941,6 +953,25 @@ bool BookWindow::Load(QString filename)
             d = new AnimalKinship(m_Player);
         else if (ele.at(0) == "Mind Over Matter")
             d = new MindOverMatter(m_Player);
+        //Magnakai:
+        else if (ele.at(0) == "Weaponmastery")
+            d = new Weaponmastery(m_Player);
+        else if (ele.at(0) == "Animal Control")
+            d = new AnimalControl(m_Player);
+        else if (ele.at(0) == "Curing")
+            d = new Curing(m_Player);
+        else if (ele.at(0) == "Invisibility")
+            d = new Invisibility(m_Player);
+        else if (ele.at(0) == "Huntmastery")
+            d = new Huntmastery(m_Player);
+        else if (ele.at(0) == "Psi-surge")
+            d = new PsiSurge(m_Player);
+        else if (ele.at(0) == "Psi-screen")
+            d = new PsiScreen(m_Player);
+        else if (ele.at(0) == "Nexus")
+            d = new Nexus(m_Player);
+        else if (ele.at(0) == "Divination")
+            d = new Divination(m_Player);
 
         if (d){
             d->FromString(discipline);
@@ -1038,7 +1069,14 @@ void BookWindow::AboutSlot()
 
 void BookWindow::AddBonusDiscipline()
 {
-    BonusDisciplineWindow* dlg = new BonusDisciplineWindow(this, m_Book, m_Player);
+    BonusDisciplineWindow* dlg = new BonusDisciplineWindow(this, m_Book, m_Player, 1);
+    while (dlg->exec() != QDialog::Accepted	){}
+    delete dlg;
+}
+
+void BookWindow::AddBonusDisciplines(int number)
+{
+    BonusDisciplineWindow* dlg = new BonusDisciplineWindow(this, m_Book, m_Player, number);
     while (dlg->exec() != QDialog::Accepted	){}
     delete dlg;
 }
@@ -1111,7 +1149,7 @@ Item* BookWindow::AddHealingPickItem(QString name, int enduranceRestore)
 
 int BookWindow::PickItems(int max)
 {
-    PickItemsWindow* dlg = new PickItemsWindow(this, m_Player, m_PickGoldCrowns, &m_PickItems, max);
+    PickItemsWindow* dlg = new PickItemsWindow(this, m_Player, m_Book->GetSerie(), m_PickGoldCrowns, &m_PickItems, max);
     while (dlg->exec() != QDialog::Accepted	){}
     int picked = dlg->GetPickedItemsCount();
     delete dlg;
@@ -1141,6 +1179,16 @@ void BookWindow::PlayPortholes()
     delete dlg;
 }
 
+int BookWindow::PlayBetGame()
+{
+    BetWindow* dlg = new BetWindow(this, m_Player);
+    dlg->exec();
+    int rounds = dlg->GetRounds();
+    delete dlg;
+
+    return rounds;
+}
+
 int BookWindow::GetRandomNumber()
 {
     RandomNumberPicker* rnd = new RandomNumberPicker(this, ui->lblDice);
