@@ -89,6 +89,7 @@ public slots:
     QString ChooseItemExceptMeals(QString title);
     QString ChooseSpecialItem(QString title);
     void AddBonusDiscipline();
+    void AddBonusDisciplines(int number);
     bool LoadNextBook();
     void show();
 
@@ -113,6 +114,7 @@ public slots:
 
     void PlayCartwheel();
     void PlayPortholes();
+    int PlayBetGame();
     int InputNumber(QString, int, int);
 };
 
