@@ -96,7 +96,7 @@ void ChooseItemWindow::ShowBackpackItems(bool excludeMeals)
     stretchZero.setHorizontalStretch(0);
 
     foreach(Item* i, m_Player->Items){
-        if (!i->GetIsSpecial()){
+        if (i->GetIsBackpackItem()){
             if (excludeMeals && i->GetIsMeal())
                 continue;
 
