@@ -9,8 +9,8 @@ Player::Player(QObject *parent) :
     BaseEndurance = 0;
     Endurance = 0;
     GoldCrowns = 0;
-    KaiDisciplines.clear();
-
+    Arrows = 0;
+    KaiDisciplines.clear();    
     m_Backpack = true;
     m_CanHunt = true;
 
@@ -25,7 +25,7 @@ Player::Player(const Player& player) :
     BaseEndurance = player.BaseEndurance;
     Endurance = player.Endurance;
     GoldCrowns = player.GoldCrowns;
-
+    Arrows = player.Arrows;
     m_Backpack = player.m_Backpack;
     m_CanHunt = player.m_CanHunt;
 
@@ -63,44 +63,32 @@ QList<Item*> Player::SpecialItems()
     return res;
 }
 
-QString Player::GetRankDescription(int kaiDisciplinesCount)
+QString Player::GetRankDescription(int serie, int kaiDisciplinesCount)
 {
-    switch (kaiDisciplinesCount)
-    {
-    case 1:
-        return "Novice";
+    QStringList kai = QStringList() << "Novice" << "Intuite" << "Doan" << "Acolyte"
+                                    << "Initiate" << "Aspirant" << "Guardian" << "Warmarn"
+                                    << "Savant" << "Master";
+
+    QStringList magnakai = QStringList() << "Kai Master" << "Kai Master Senior" << "Kai Master Superior"
+                                         << "Primate" << "Tutelary" << "Principalin" << "Mentora"
+                                         << "Scion-kai" << "Archmaster" << "Kai Grand Master";
+
+    switch (serie){
+    case Book::Kai:
+        return kai.at(kaiDisciplinesCount - 1);
         break;
-    case 2:
-        return "Intuite";
+    case Book::Magnakai:
+        return magnakai.at(kaiDisciplinesCount - 1);
         break;
-    case 3:
-        return "Doan";
+    case Book::GrandMaster:
+        return "";
         break;
-    case 4:
-        return "Acolyte";
-        break;
-    case 5:
-        return "Initiate";
-        break;
-    case 6:
-        return "Aspirant";
-        break;
-    case 7:
-        return "Guardian";
-        break;
-    case 8:
-        return "Warmarn";
-        break;
-    case 9:
-        return "Savant";
-        break;
-    case 10:
-        return "Master";
-        break;
-    default:
+    case Book::NewOrder:
         return "";
         break;
     }
+
+    return "";
 }
 
 int Player::MealsCount()
@@ -127,36 +115,60 @@ int Player::GetCombatSkill()
     }
 
     foreach (KaiDiscipline* d, KaiDisciplines){
-        result += d->CombatSkillDelta;
+        if (d->Active){
+            result += d->CombatSkillDelta;
 
-        Weaponskill* ws = qobject_cast<Weaponskill*>(d);
-        if (ws){
-            foreach(Item* i, Items){
-                if (i->GetIsWeapon()){
-                    Weapon* w = (Weapon*)i;
-                    if (w->GetIsEquipped() && w->Classes().contains(ws->Weapon)){
-                        result += 2;
-                        break;
+            Weaponskill* ws = qobject_cast<Weaponskill*>(d);
+            if (ws){
+                foreach(Item* i, Items){
+                    if (i->GetIsWeapon()){
+                        Weapon* w = (Weapon*)i;
+                        if (w->GetIsEquipped() && w->Classes().contains(ws->Weapon)){
+                            result += 2;
+                            break;
+                        }
                     }
                 }
             }
+
+            Weaponmastery* wm = qobject_cast<Weaponmastery*>(d);
+            if (wm){
+                bool done = false;
+                foreach(Item* i, Items){
+                    if (i->GetIsWeapon()){
+                        Weapon* w = (Weapon*)i;
+                        if (w->GetIsEquipped()){
+                            foreach (int wc, w->Classes()){
+                                if (wm->Weapons.contains(wc)){
+                                    result += 3;
+                                    done = true;
+                                    break;
+                                }
+                            }
+
+                        }
+                    }
+                    if (done)
+                        break;
+                }
+            }
+
+        }else{
+            //Special case: Psi-surge when deactivate acts like Mindblast
+            PsiSurge* ps = qobject_cast<PsiSurge*>(d);
+            if (ps)
+                result += 2;
         }
     }
 
-    if (Weapons().count() == 0)
-        result -= 4;
-
-    return result;
-}
-
-int Player::GetBaseEndurance()
-{
-    int result = BaseEndurance;
-    foreach (Item* i, Items){
-        if (i->GetIsEquipped())
-            result += i->GetEnduranceDelta();
+    foreach (LoreCircle* lc, LoreCircles::Circles){
+        if (lc->Check(this))
+            result += lc->CombatSkillBonus;
     }
 
+    if (GetEquippedWeapon() == NULL)
+        result -= 4;
+
     return result;
 }
 
@@ -169,20 +181,51 @@ int Player::GetCombatSkill(Enemy* enemy)
     }
 
     foreach (KaiDiscipline* d, KaiDisciplines){
-        if (!enemy->DisciplineImmunities.contains(d->Name))
-            result += d->CombatSkillDelta;
+        if (d->Active){
+            if (!enemy->DisciplineImmunities.contains(d->Name))
+                result += d->CombatSkillDelta;
 
-        Weaponskill* ws = qobject_cast<Weaponskill*>(d);
-        if (ws){
-            foreach(Item* i, Items){
-                if (i->GetIsWeapon()){
-                    Weapon* w = (Weapon*)i;
-                    if (w->GetIsEquipped() && w->Classes().contains(ws->Weapon)){
-                        result += 2;
-                        break;
+            Weaponskill* ws = qobject_cast<Weaponskill*>(d);
+            if (ws){
+                foreach(Item* i, Items){
+                    if (i->GetIsWeapon()){
+                        Weapon* w = (Weapon*)i;
+                        if (w->GetIsEquipped() && w->Classes().contains(ws->Weapon)){
+                            result += 2;
+                            break;
+                        }
                     }
                 }
             }
+
+            Weaponmastery* wm = qobject_cast<Weaponmastery*>(d);
+            if (wm){
+                bool done = false;
+                foreach(Item* i, Items){
+                    if (i->GetIsWeapon()){
+                        Weapon* w = (Weapon*)i;
+                        if (w->GetIsEquipped()){
+                            foreach (int wc, w->Classes()){
+                                if (wm->Weapons.contains(wc)){
+                                    result += 3;
+                                    done = true;
+                                    break;
+                                }
+                            }
+
+                        }
+                    }
+                    if (done)
+                        break;
+                }
+            }
+        }else{
+            //Special case: Psi-surge when deactivate acts like Mindblast
+            if (!enemy->DisciplineImmunities.contains("Mindblast")){
+                PsiSurge* ps = qobject_cast<PsiSurge*>(d);
+                if (ps)
+                    result += 2;
+            }
         }
     }
 
@@ -192,6 +235,21 @@ int Player::GetCombatSkill(Enemy* enemy)
     return result;
 }
 
+int Player::GetBaseEndurance()
+{
+    int result = BaseEndurance;
+    foreach (Item* i, Items){
+        if (i->GetIsEquipped())
+            result += i->GetEnduranceDelta();
+    }
+
+    foreach (LoreCircle* lc, LoreCircles::Circles){
+        if (lc->Check(this))
+            result += lc->EnduranceBonus;
+    }
+    return result;
+}
+
 void Player::RemoveDiscipline(QString name)
 {
     KaiDiscipline* remove = NULL;
@@ -205,11 +263,27 @@ void Player::RemoveDiscipline(QString name)
         KaiDisciplines.removeOne(remove);
 }
 
+void Player::RemoveDisciplines()
+{
+    foreach (KaiDiscipline* d, KaiDisciplines)
+        delete d;
+    KaiDisciplines.clear();
+}
+
 int Player::GetDisciplineCount()
 {
     return KaiDisciplines.count();
 }
 
+KaiDiscipline* Player::GetDiscipline(QString name)
+{
+    foreach (KaiDiscipline* d, KaiDisciplines){
+        if (QString::compare(d->Name, name, Qt::CaseInsensitive) == 0)
+            return d;
+    }
+    return NULL;
+}
+
 bool Player::HasDiscipline(QString name)
 {
     foreach (KaiDiscipline* d, KaiDisciplines){
@@ -251,6 +325,29 @@ bool Player::HasWeaponskillBonus()
     return false;
 }
 
+bool Player::HasLoreCircle(QString name)
+{
+    foreach (LoreCircle* lc, LoreCircles::Circles){
+        if (QString::compare(lc->Name(), name, Qt::CaseInsensitive) == 0)
+            return lc->Check(this);
+    }
+
+    return false;
+}
+
+bool Player::HasWeaponmasteryIn(QString className)
+{
+    foreach (KaiDiscipline* d, KaiDisciplines){
+        if (QString::compare(d->Name, "Weaponmastery", Qt::CaseInsensitive) == 0){
+            Weaponmastery* ws = qobject_cast<Weaponmastery*>(d);
+            if (ws)
+                return ws->Weapons.contains(Weapon::GetClass(className));
+
+        }
+    }
+    return false;
+}
+
 int Player::GetEndurance()
 {
     return Endurance;
@@ -267,6 +364,11 @@ void Player::SetEndurance(int endurance)
         Endurance = GetBaseEndurance();
 }
 
+void Player::ForceEndurance(int endurance)
+{
+    Endurance = endurance;
+}
+
 void Player::CheckEndurance()
 {
     if (Endurance > GetBaseEndurance())
@@ -448,7 +550,12 @@ int Player::SpecialItemsCount()
 
 int Player::ItemsCount()
 {
-    return GetItems().count();
+    int res = 0;
+    foreach(Item* i, Items){
+        if (i->GetIsBackpackItem())
+            res++;
+    }
+    return res;
 }
 
 void Player::SetHasBackpack(bool value)
@@ -468,11 +575,18 @@ void Player::SetHasBackpack(bool value)
     }
 }
 
+void Player::SetHasQuiver(bool value)
+{
+    m_Quiver = value;
+    if (!m_Quiver)
+        Arrows = 0;
+}
+
 bool Player::IsBackpackFull()
 {
     int size = 0;
     foreach(Item* i, Items){
-        if (!i->GetIsSpecial())
+        if (i->GetIsBackpackItem())
             size += i->GetSize();
     }
 
@@ -644,6 +758,21 @@ void Player::ClearProperties()
     Properties.clear();
 }
 
+int Player::GetBowBonus(bool includeDisciplines)
+{
+    int bonus = 0;
+    if (includeDisciplines){
+        if (HasWeaponmasteryIn("Bow"))
+            bonus += 3;
+    }
+    foreach (Weapon* w, Weapons()){
+        if (w->Classes().contains(Weapon::Bow))
+            bonus += w->GetRandomBonus();
+    }
+
+    return bonus;
+}
+
 void Player::Dump()
 {
     qDebug() << "Properties:";
