@@ -27,6 +27,8 @@ protected:
 private:
     Ui::FightWindow *ui;
 
+    bool m_UpdatingData;
+    int m_LastRandomNumber;
     RandomNumberPicker* m_RandomPicker;
     bool m_Close;
     int m_PlayerDamage;
@@ -43,6 +45,7 @@ private:
     Enemy* m_Enemy;
     int m_AttackMultiplier;
     int m_AttackBonus;
+    int m_RandomBonus;
 
     void UpdateData();
     void Evaluate(int number);
@@ -54,6 +57,7 @@ private slots:
     void AttackSlot();
     void EvadeSlot();
     void RandomSlot(int);
+    void DisciplineChangedSlot(int index);
 
 public slots:
     void MessageBox(QString title, QString message);
@@ -64,9 +68,11 @@ public slots:
     bool GetCanEvade();
     void SetCanEvade(bool);
     int GetRound();
+    int GetLastRandomNumber();
     int GetLostEndurancePoints();
     int GetEnemyLostEndurancePoints() { return m_EnemyPointsLost; }
     void Close();
+    void SetRandomBonus(int value) { m_RandomBonus = value; }
     void SetAttackBonus(int value) { m_AttackBonus = value; }
     void SetAttackMultiplier(int value) { m_AttackMultiplier = value; }
     void SetSurpriseRounds(int value) { m_SurpriseRound = value; }
