@@ -2,7 +2,7 @@
 #include "ui_pickitemswindow.h"
 #include "commonstatic.h"
 
-PickItemsWindow::PickItemsWindow(QWidget *parent, Player* player, int goldCrowns, QList<Item*>* items, int max) :
+PickItemsWindow::PickItemsWindow(QWidget *parent, Player* player, int serie, int goldCrowns, QList<Item*>* items, int max) :
     QDialog(parent),
     ui(new Ui::PickItemsWindow)
 {
@@ -11,6 +11,7 @@ PickItemsWindow::PickItemsWindow(QWidget *parent, Player* player, int goldCrowns
     setAttribute(Qt::WA_Maemo5AutoOrientation);
 #endif
 
+    m_Serie = serie;
     m_Player = player;
     m_GoldCrowns = goldCrowns;
     m_SelectedGoldCrowns = 0;
@@ -49,6 +50,10 @@ void PickItemsWindow::ShowData(bool full)
     QSizePolicy stretchZero;
     stretchZero.setHorizontalStretch(0);
 
+#ifdef Q_WS_MAEMO_5
+    ui->pbnDropWeapon1->setMaximumSize(120, 50);
+    ui->pbnDropWeapon2->setMaximumSize(120, 50);
+#endif
     if (full){
         while ((child = ui->layPickItems->takeAt(0)) != 0) {
             delete child->widget();
@@ -109,7 +114,19 @@ void PickItemsWindow::ShowData(bool full)
         }
     }
 
+    switch (m_Serie){
+    case Book::Kai:
+        ui->lblQuiver->setVisible(false);
+        ui->chkQuiver->setVisible(false);
+        ui->lblArrowsD->setVisible(false);
+        ui->lblArrows->setVisible(false);
+        break;
+    default:
+        break;
+    }
     ui->lblCrowns->setText(QString::number(m_Player->GetGoldCrowns()));
+    ui->lblArrows->setText(QString::number(m_Player->Arrows));
+    ui->chkQuiver->setChecked(m_Player->HasQuiver());
     ui->pbnDropWeapon1->setEnabled(false);
     ui->pbnDropWeapon2->setEnabled(false);
     QList<Weapon*> weapons = m_Player->Weapons();
@@ -159,7 +176,11 @@ void PickItemsWindow::ShowData(bool full)
                 QPushButton* pbn = new QPushButton(this);
                 pbn->setObjectName(QString::number(index));
                 pbn->setText("Discard");
+#ifdef Q_WS_MAEMO_5
+                pbn->setMaximumSize(120, 50);
+#else
                 pbn->setMaximumSize(75, 50);
+#endif
                 connect(pbn, SIGNAL(clicked()), this, SLOT(DropItemSlot()));
                 ui->layItems->addWidget(pbn, row, 3);
 
@@ -212,8 +233,22 @@ void PickItemsWindow::CheckItemSlot(bool value)
                     msgBox.exec();
                     chk->setChecked(false);
                     return;
+                } else if (i->GetIsQuiver() && m_Player->HasQuiver()){
+                    QMessageBox msgBox(this);
+                    msgBox.setText("You have the quiver and cannot carry another one.");
+                    msgBox.exec();
+                    chk->setChecked(false);
+                    return;
                 }else if (!i->GetIsSpecial()){
-                    if (!HasBackpack()){
+                    if (i->GetIsArrow()){
+                        if (!m_Player->HasQuiver()){
+                            QMessageBox msgBox(this);
+                            msgBox.setText("You don't have the quiver and cannot carry arrows.");
+                            msgBox.exec();
+                            chk->setChecked(false);
+                            return;
+                        }
+                    }else if (!HasBackpack()){
                         QMessageBox msgBox(this);
                         msgBox.setText("You don't have the backpack and cannot carry any item.");
                         msgBox.exec();
@@ -258,7 +293,9 @@ void PickItemsWindow::DoneSlot()
         if (w)
             m_Player->Items.append(w);
         else{
-            if (i->GetIsBackpack()){
+            if (i->GetIsQuiver()){
+                m_Player->SetHasQuiver(true);
+            }else if (i->GetIsBackpack()){
                 m_Player->SetHasBackpack(true);
             }else{
                 int qty = i->GetQuantity();
