@@ -71,6 +71,9 @@ void ShopWindow::ShowData()
 
     int index = 0;
     foreach(ShopItem* i, m_Section->ShopItems){
+        if (i->Price < 0)
+            continue;
+
         lbl = new QLabel(this);
         if (i->GetQuantity() > 1)
             lbl->setText(QString("%1 (%2)").arg(i->Name).arg(i->GetQuantity()));
@@ -93,7 +96,8 @@ void ShopWindow::ShowData()
         pbn->setObjectName(QString::number(index++));
         pbn->setText("Buy");
         if (i->Price > m_Player->GetGoldCrowns() ||
-            (i->GetIsBackpack() && m_Player->HasBackpack()))
+            (i->GetIsBackpack() && m_Player->HasBackpack()) ||
+            (i->GetIsQuiver() && m_Player->HasQuiver()))
             pbn->setEnabled(false);
         pbn->setMaximumSize(75, 50);
         connect(pbn, SIGNAL(clicked()), this, SLOT(BuyItemSlot()));
@@ -101,7 +105,20 @@ void ShopWindow::ShowData()
         row++;
     }
 
+    switch (((Book*)m_Section->parent())->GetSerie()){
+    case Book::Kai:
+        ui->lblQuiver->setVisible(false);
+        ui->chkQuiver->setVisible(false);
+        ui->lblArrowsD->setVisible(false);
+        ui->lblArrows->setVisible(false);
+        break;
+    default:
+        break;
+    }
+
     ui->lblCrowns->setText(QString::number(m_Player->GetGoldCrowns()));
+    ui->lblArrows->setText(QString::number(m_Player->Arrows));
+    ui->chkQuiver->setChecked(m_Player->HasQuiver());
     ui->pbnDropWeapon1->setEnabled(false);
     ui->pbnDropWeapon2->setEnabled(false);
     int sell = 0;
@@ -199,6 +216,20 @@ void ShopWindow::BuyItemSlot()
         msgBox.exec();
         return;
     }else{
+        if (i->GetIsArrow() && !m_Player->HasQuiver()){
+            QMessageBox msgBox(this);
+            msgBox.setText("You don't have the quiver and cannot carry arrows.");
+            msgBox.exec();
+            return;
+        }
+
+        if (i->GetIsArrow() && m_Player->Arrows == 6){
+            QMessageBox msgBox(this);
+            msgBox.setText("You cannot carry more arrows.");
+            msgBox.exec();
+            return;
+        }
+
         if (!i->GetIsSpecial() && !m_Player->HasBackpack()){
             QMessageBox msgBox(this);
             msgBox.setText("You don't have the backpack and cannot carry any item.");
@@ -220,7 +251,11 @@ void ShopWindow::BuyItemSlot()
         if (i->IsWeapon())
             m_Player->Items.append((Weapon*)i);
         else{
-            if (i->GetIsBackpack())
+            if (i->GetIsQuiver())
+                m_Player->SetHasQuiver(true);
+            else if (i->GetIsArrow())
+                m_Player->Arrows += i->GetQuantity();
+            else if (i->GetIsBackpack())
                 m_Player->SetHasBackpack(true);
             else
                 m_Player->Items.append((Item*)i);
