@@ -8,7 +8,7 @@
 #include "commonstatic.h"
 #include "ruleswindow.h"
 
-StatusWindow::StatusWindow(QWidget *parent, int serie, Player* player, Section* section, QScriptEngine* engine, QScriptValue* functions) :
+StatusWindow::StatusWindow(QWidget *parent, Player* player, Section* section, QScriptEngine* engine, QScriptValue* functions) :
     QMainWindow(parent),
     ui(new Ui::StatusWindow)
 {
@@ -30,6 +30,7 @@ StatusWindow::StatusWindow(QWidget *parent, int serie, Player* player, Section*
     ui->lblSectionItems->setPalette(secondaryPalette);
     ui->lblStatus->setPalette(secondaryPalette);
     ui->lblDisciplines->setPalette(secondaryPalette);
+    ui->lblRank->setPalette(secondaryPalette);
     ui->lblWeapons->setPalette(secondaryPalette);
     ui->lblItems->setPalette(secondaryPalette);
     ui->lblSpecialItems->setPalette(secondaryPalette);
@@ -43,10 +44,11 @@ StatusWindow::StatusWindow(QWidget *parent, int serie, Player* player, Section*
     connect(ui->pbnEquip2, SIGNAL(clicked()), this, SLOT(EquipWeapon2Slot()));
     connect(ui->pbnPickGoldCrowns, SIGNAL(clicked()), this, SLOT(TakeGoldCrownsSlot()));
 
-    m_Serie = serie;
     m_Engine = engine;
     m_Functions = functions;
     m_Section = section;
+    m_Book = (Book*)m_Section->parent();
+    m_Serie = m_Book->GetSerie();
     m_Player = player;
     ShowData();
 }
@@ -72,6 +74,31 @@ void StatusWindow::exec()
 
 void StatusWindow::ShowData()
 {
+    switch (m_Serie){
+    case Book::Kai:
+        ui->lblDisciplines->setText("Kai Disciplines:");
+        ui->lblQuiver->setVisible(false);
+        ui->chkQuiver->setVisible(false);
+        ui->lblArrowsD->setVisible(false);
+        ui->lblArrows->setVisible(false);
+        ui->lblWeaponChecklist->setVisible(false);
+        break;
+    case Book::Magnakai:
+        ui->lblDisciplines->setText("Magnakai Disciplines:");
+        ui->lblQuiver->setVisible(true);
+        ui->chkQuiver->setVisible(true);
+        ui->lblArrowsD->setVisible(true);
+        ui->lblArrows->setVisible(true);
+        ui->lblWeaponChecklist->setVisible(true);
+        break;
+    case Book::GrandMaster:
+        ui->lblDisciplines->setText("Grand Master Disciplines:");
+        break;
+    case Book::NewOrder:
+        ui->lblDisciplines->setText("New Order Disciplines:");
+        break;
+    }
+
     if (!m_Section || !m_Section->HasPickableItems()){
         ui->lblSectionItems->setVisible(false);
         ui->lineSection->setVisible(false);
@@ -112,10 +139,12 @@ void StatusWindow::ShowData()
         }
     }
 
-    ui->lblSkill->setText(QString::number(m_Player->GetCombatSkill()));
+    ui->lblSkill->setText(QString("%1/%2").arg(m_Player->GetCombatSkill()).arg(m_Player->GetBaseCombatSkill()));
     ui->lblEndurance->setText(QString("%1/%2").arg(m_Player->Endurance).arg(m_Player->GetBaseEndurance()));
     ui->lblCrowns->setText(QString("%1/50").arg(m_Player->GoldCrowns));
     ui->lblMeals->setText(QString::number(m_Player->MealsCount()));
+    ui->chkQuiver->setChecked(m_Player->HasQuiver());
+    ui->lblArrows->setText(QString::number(m_Player->Arrows));
 
     QList<Weapon*> weapons = m_Player->Weapons();
     ui->pbnDropWeapon1->setEnabled(false);
@@ -125,7 +154,7 @@ void StatusWindow::ShowData()
     if (weapons.count() > 0){
         ui->lblWeapon1->setText(weapons.at(0)->Name);
         ui->pbnDropWeapon1->setEnabled(true);
-        ui->pbnEquip1->setEnabled(weapons.at(0)->GetCanBeEquipped());
+        ui->pbnEquip1->setEnabled(weapons.at(0)->GetCanBeEquipped() && !weapons.at(0)->Classes().contains(Weapon::Bow));
         if (weapons.at(0)->GetIsEquipped()){
             ui->pbnEquip1->setText("Unequip");
 #ifdef Q_WS_MAEMO_5
@@ -144,7 +173,7 @@ void StatusWindow::ShowData()
     if (weapons.count() > 1){
         ui->lblWeapon2->setText(weapons.at(1)->Name);
         ui->pbnDropWeapon2->setEnabled(true);
-        ui->pbnEquip2->setEnabled(weapons.at(1)->GetCanBeEquipped());
+        ui->pbnEquip2->setEnabled(weapons.at(1)->GetCanBeEquipped() && !weapons.at(1)->Classes().contains(Weapon::Bow));
         if (weapons.at(1)->GetIsEquipped()){
             ui->pbnEquip2->setText("Unequip");
 #ifdef Q_WS_MAEMO_5
@@ -178,7 +207,7 @@ void StatusWindow::ShowData()
     }
     if (!row){
         QLabel* lbl = new QLabel(this);
-        lbl->setText("None");
+        lbl->setText("None (-4 Combat Skill)");
         lbl->setWordWrap(true);
         ui->layEquippedWeapons->addWidget(lbl, row, 0);
     }
@@ -207,12 +236,16 @@ void StatusWindow::ShowData()
     }
 
     ClearLayout(ui->layKaiDisciplines);
+    ClearLayout(ui->layWeaponChecklist);
     QSizePolicy stretchZero;
     stretchZero.setHorizontalStretch(0);
     QSizePolicy stretchOne;
     stretchOne.setHorizontalStretch(1);
     row = 0;
     foreach (KaiDiscipline* d, m_Player->KaiDisciplines){
+        if (d->Serie != m_Serie)
+            continue;
+
         QLabel* lbl = new QLabel(this);
         lbl->setSizePolicy(stretchZero);
         lbl->setText(QString("<b>%1:</b>").arg(row + 1));
@@ -226,9 +259,33 @@ void StatusWindow::ShowData()
 
         lbl = new QLabel(this);
         lbl->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
-        lbl->setText(Player::GetRankDescription(row + 1));
+        lbl->setText(Player::GetRankDescription(m_Serie, row + 1));
         ui->layKaiDisciplines->addWidget(lbl, row, 2);
         row++;
+
+        //Weaponmastery Checklist
+        Weaponmastery* wm = qobject_cast<Weaponmastery*>(d);
+        if (wm){
+            QList<int> weapons = QList<int>() << Weapon::Dagger << Weapon::Mace << Weapon::WarHammer
+                                              << Weapon::Axe << Weapon::Quarterstaff << Weapon::Spear
+                                              << Weapon::ShortSword << Weapon::Bow << Weapon::Sword
+                                              << Weapon::Broadsword;
+
+            int wrow = 0;
+            foreach (int w, weapons){
+                lbl = new QLabel(this);
+                lbl->setText(Weapon::ClassDescription(w));
+                ui->layWeaponChecklist->addWidget(lbl, wrow, 0);
+
+                QCheckBox* chk = new QCheckBox(this);
+                chk->setLayoutDirection(Qt::RightToLeft);
+                chk->setEnabled(false);
+                chk->setChecked(wm->Weapons.contains(w));
+                ui->layWeaponChecklist->addWidget(chk, wrow, 1);
+
+                wrow++;
+            }
+        }
     }
 
     ClearLayout(ui->layItems);
@@ -508,6 +565,19 @@ void StatusWindow::TakeItemSlot()
     }else{
         //Take arrows:
         if (i->GetIsArrow()){
+            if (!m_Player->HasQuiver()){
+                QMessageBox msgBox(this);
+                msgBox.setText("You don't have the quiver and cannot carry arrows.");
+                msgBox.exec();
+                return;
+            }
+            if (m_Player->Arrows == 6){
+                QMessageBox msgBox(this);
+                msgBox.setText("You cannot carry more arrows.");
+                msgBox.exec();
+                return;
+            }
+
             m_Player->Arrows += i->GetQuantity();
             m_Section->Items.removeOne(i);
             ShowData();
@@ -585,8 +655,7 @@ void StatusWindow::ClearLayout(QLayout* layout)
 
 void StatusWindow::DiscipleLinkSlot(QString link)
 {
-    Book* book = (Book*)m_Section->parent();
-    RulesWindow* dlg = new RulesWindow(this, book->BaseDirectory);
+    RulesWindow* dlg = new RulesWindow(this, m_Book->BaseDirectory);
     dlg->show();
     dlg->ScrollToAnchor(link);
 }
