@@ -16,7 +16,7 @@ class StatusWindow : public QMainWindow
     Q_OBJECT
 
 public:
-    explicit StatusWindow(QWidget *parent = 0, int serie=Book::Kai, Player* player=0, Section* section=0, QScriptEngine* engine=0, QScriptValue* functions=0);
+    explicit StatusWindow(QWidget *parent = 0, Player* player=0, Section* section=0, QScriptEngine* engine=0, QScriptValue* functions=0);
     ~StatusWindow();
 
     void exec();
@@ -34,6 +34,7 @@ private:
     QScriptValue* m_Functions;
     QList<Item*> m_UsedItems;
     QEventLoop* m_Loop;
+    Book* m_Book;
     Section* m_Section;
     Player* m_Player;
 
